<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ne">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>अब</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 नयाँ सूचना</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 मिनिटहरू पहिले</translation>
    </message>
</context>
</TS>